# U-Phy Device Generator

The U-Phy Device Generator is a tool designed to create fieldbus
device description files and U-Phy source code directly from device
models generated by the U-Phy Device Builder.

Maintaining synchronization between source code and description files
can be challenging. Therefore, having a tool that generates both from
a single source of truth is extremely beneficial.

## Developing

Python Poetry is recommended. See
https://python-poetry.org/docs/#installation for installation
instructions.

    $ cd /path/to/upgen
    $ poetry install
    $ poetry shell
